drop database if exists db_jabones_oasis;
create database db_jabones_oasis;
use db_jabones_oasis;

create table ingredientes(
	id_ingrediente int auto_increment primary key,
    nombre varchar(50),
    precio double,
    tipo int -- 1 esencia, 2 aceite, 3 colorante 
);

create table jabones(
	id_jabon int auto_increment primary key,
    nombre varchar(50),
    descripcion varchar(250),
    img varchar(250),
    precio_base double
);

create table resenas(
	id_resena int auto_increment primary key,
    id_jabon int,
    comentario text,
    foreign key(id_jabon) references jabones(id_jabon)
    on delete cascade on update cascade
);

create table pedidos(
	id_pedido int auto_increment primary key,
    direccion_envio varchar(250),
    telefono_contacto varchar(250),
    correo_contacto varchar(250),
    total double
);

create table detalles_pedidos(
	id_detalle_pedido int auto_increment primary key,
    id_pedido int,
    id_jabon int,
    subtotal double,
    foreign key(id_pedido) references pedidos(id_pedido)
    on delete cascade on update cascade,
    foreign key(id_jabon) references jabones(id_jabon)
    on delete cascade on update cascade
);

create table adicionales_jabones(
	id_adicional_jabon int auto_increment primary key,
    id_detalle_pedido int,
    id_ingrediente int,
    foreign key(id_detalle_pedido) references detalles_pedidos(id_detalle_pedido)
    on delete cascade on update cascade,
    foreign key(id_ingrediente) references ingredientes(id_ingrediente)
    on delete cascade on update cascade
);

-- 1 esencia, 2 aceite, 3 colorante
insert into ingredientes(nombre,precio,tipo) values
('Escencia de Menta', 5000, 1),
('Escencia de Vainilla', 4000, 1),
('Escencia de Coco', 5500, 1),
('Aceite de Coco', 2000, 2),
('Aceite de Almendra', 2400,2),
('Café', 1500, 3),
('Cúrcuma', 2000,3);

insert into jabones (nombre, descripcion, precio_base) values
('Jabón de avena', 'Hidratante y suave para pieles sensibles', 5000),
('Jabón de carbón activado', 'Purificante y desintoxicante', 6500),
('Jabón de coco', 'Exfoliante y nutritivo', 4500),
('Jabón de aloe vera', 'Calmante y regenerador', 5500),
('Jabón artesanal de lavanda', 'Relajante y aromático', 6000);
    
insert into resenas (id_jabon, comentario)values
(1, 'Me encanta este jabón, deja mi piel muy suave.'),
(2, 'Elimina las impurezas de mi piel de manera efectiva.'),
(3, 'El aroma a coco es delicioso y deja mi piel muy hidratada.'),
(4, 'Ideal para después de la exposición al sol.'),
(5, 'El aroma a lavanda me relaja mucho.'),
(2, 'Lo recomiendo ampliamente para pieles grasas.'),
(3, 'Excelente producto, volveré a comprarlo.');
    
insert into pedidos (direccion_envio, telefono_contacto, correo_contacto, total)values
('Calle Principal 123, San José', '2222-3333', 'cliente1@example.com', 15000),
('Avenida Central 456, Cartago', '2555-6666', 'cliente2@example.com', 12000),
('Urbanización Los Lagos, Alajuela', '2888-9999', 'cliente3@example.com', 8000);
    
insert into detalles_pedidos (id_pedido, id_jabon, subtotal)values
(1, 1, 5000),
(1, 2, 6500),
(2, 3, 4500),
(3, 4, 5500);

insert into adicionales_jabones (id_detalle_pedido, id_ingrediente)values
(1, 1), 
(2, 2),
(3, 3);
