@extends('appAdmin.appAdmin')
@section('contenido')
    <div class="row">
        <div class="col-12">
            <div class="card shadow-lg p-3 bg-body-tertiary">
                <div class="card-header">
                    <h4 class="card-title">Pedidos</h4>
                </div>
                <div class="card-body">
                    <div class="table-responsive">
                        <table id="tabla_pedidos" class="display table table-striped table-hover">
                            <thead>
                                <tr>
                                    <th>#</th>
                                    <th>Dirección</th>
                                    <th>Teléfono</th>
                                    <th>Correo</th>
                                    <th>Total</th>
                                    <th>Estado</th>
                                    <th>Ver</th>
                                    <th>Eliminar</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach ($data as $item)
                                    <tr>
                                        <td>{{ $item->id_pedido }}</td>
                                        <td>{{ $item->direccion_envio }}</td>
                                        <td>{{ $item->telefono_contacto }}</td>
                                        <td>{{ $item->correo_contacto }}</td>
                                        <td>{{ $item->total }}</td>
                                        <td>
                                            <select name="estado" id="select-{{ $item->id_pedido }}" 
                                                class="form-control actualizar-estado" data-id="{{ $item->id_pedido }}">
                                                <option value="1" {{ $item->estado == 1 ? 'selected' : '' }}>Recibido</option>
                                                <option value="2" {{ $item->estado == 2 ? 'selected' : '' }}>En proceso</option>
                                                <option value="3" {{ $item->estado == 3 ? 'selected' : '' }}>Enviado</option>
                                            </select>
                                        </td>
                                        <td class="text-center">
                                            <a href="{{route('pedidos.show',$item->id_pedido)}}" class="btn btn-primary">
                                                <i class="fa-regular fa-eye"></i>
                                            </a>
                                        </td>
                                        <td class="text-center">
                                            <button type="button" data-bs-toggle="modal" data-id="{{ $item->id_pedido }}"
                                                data-bs-target="#modal_eliminar" class="btn btn-danger btn-eliminar">
                                                <i class="fa fa-times"></i>
                                            </button>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal para eliminar pedido -->
    <div class="modal fade" id="modal_eliminar" tabindex="-1" role="dialog" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Eliminar Pedido</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="" method="POST" id="form_eliminar">
                    @csrf
                    @method('DELETE')
                    <div class="modal-body text-center">
                        <h5>¿Estás seguro de eliminar el pedido <span id="pedido_id"></span>?</h5>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-light" data-bs-dismiss="modal">Cancelar</button>
                        <button type="submit" class="btn btn-danger">Eliminar</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Modal de estado actualizado -->
    <div class="modal fade" id="modal_actualizado" tabindex="-1" role="dialog" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Estado Actualizado</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body text-center">
                    <h5>El estado del pedido se ha actualizado correctamente.</h5>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-success" data-bs-dismiss="modal">Aceptar</button>
                </div>
            </div>
        </div>
    </div>
@endsection

@section('js')
    <script>
        $(document).ready(function () {
            // Inicializar DataTable
            var tablaPedidos = $('#tabla_pedidos').DataTable({
                order: [[0, 'desc']],
                columnDefs: [
                    { targets: [5, 6], orderable: false },
                ],
            });

            // Manejo del modal para eliminar
            $(document).on('click', '.btn-eliminar', function () {
                var idPedido = $(this).data('id');
                var action = "{{ route('pedidos.destroy', ':id') }}".replace(':id', idPedido);

                $('#form_eliminar').attr('action', action);
                $('#pedido_id').text(idPedido);
            });

            // Actualizar estado del pedido
            $('.actualizar-estado').change(function () {
                var idPedido = $(this).data('id');
                var nuevoEstado = $(this).val();

                $.ajax({
                    url: "{{ route('pedidos.update', ':id') }}".replace(':id', idPedido),
                    method: 'PUT',
                    data: {
                        _token: "{{ csrf_token() }}",
                        estado: nuevoEstado,
                    },
                    success: function () {
                    },
                });
                var modal = new bootstrap.Modal(document.getElementById('modal_actualizado'));
                modal.show();
            });
        });
    </script>
@endsection
