@extends('appAdmin.appAdmin')
@section('contenido')
    <div class="row">
        <div class="col-12">
            <div class="card shadow-lg p-3 bg-body-tertiary">
                <div class="card-header">
                    <div class="row">
                        <div class="col">
                            <h4 class="card-title">
                                Pedido #{{$item->id_pedido}}
                            </h4>
                        </div>
                        <div class="col text-end">
                            <a href="{{route('pedidos.index')}}" class="btn btn-success">
                                Regresar
                            </a>
                            <button type="button" data-bs-toggle="modal" data-id="{{ $item->id_pedido }}"
                                data-bs-target="#modal_eliminar" class="btn btn-danger btn-eliminar">
                                Eliminar
                            </button>
                        </div>
                    </div>
                </div>

                <!-- Modal para eliminar pedido -->
                <div class="modal fade" id="modal_eliminar" tabindex="-1" role="dialog" aria-hidden="true">
                    <div class="modal-dialog" role="document">
                        <div class="modal-content">
                            <div class="modal-header">
                                <h5 class="modal-title">Eliminar Pedido</h5>
                                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                            </div>
                            <form action="" method="POST" id="form_eliminar">
                                @csrf
                                @method('DELETE')
                                <div class="modal-body text-center">
                                    <h5>¿Estás seguro de eliminar el pedido <span id="pedido_id"></span>?</h5>
                                </div>
                                <div class="modal-footer">
                                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">Cancelar</button>
                                    <button type="submit" class="btn btn-danger">Eliminar</button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
                <!-- Modal de estado actualizado -->
                <div class="modal fade" id="modal_actualizado" tabindex="-1" role="dialog" aria-hidden="true">
                    <div class="modal-dialog" role="document">
                        <div class="modal-content">
                            <div class="modal-header">
                                <h5 class="modal-title">Estado Actualizado</h5>
                                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                            </div>
                            <div class="modal-body text-center">
                                <h5>El estado del pedido se ha actualizado correctamente.</h5>
                            </div>
                            <div class="modal-footer">
                                <button type="button" class="btn btn-success" data-bs-dismiss="modal">Aceptar</button>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-12 p-1">
                            <label>Dirección</label>
                            <h5>{{$item->direccion_envio}}</h5>
                        </div>
                        <div class="col-6 p-1">
                            <label>Teléfono</label>
                            <h5>{{$item->telefono_contacto}}</h5>
                        </div>
                        <div class="col-6 p-1">
                            <label>Correo</label>
                            <h5>{{$item->correo_contacto}}</h5>
                        </div>
                        <div class="col-6 p-1">
                            <label>Estado</label>
                            <select name="estado" id="select-{{ $item->id_pedido }}" 
                                class="form-control actualizar-estado" data-id="{{ $item->id_pedido }}">
                                <option value="1" {{ $item->estado == 1 ? 'selected' : '' }}>Recibido</option>
                                <option value="2" {{ $item->estado == 2 ? 'selected' : '' }}>En proceso</option>
                                <option value="3" {{ $item->estado == 3 ? 'selected' : '' }}>Enviado</option>
                            </select>
                        </div>
                        <div class="col-6 p-1">
                            <label>Total</label>
                            <h5>{{$item->total}}</h5>
                        </div>
                        <div class="col-12">
                            <div class="mt-3">
                                <h4>Detalles</h4>
                            </div>
                            <div class="table-responsive mt-2">
                                <table id="tabla_detalles" class="display table table-striped table-hover">
                                    <thead>
                                        <tr>
                                            <th>Jabon</th>
                                            <th>Adicionales</th>
                                            <th>Subtotal</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        @foreach ($item->detalles_pedido as $detalle)
                                            <tr>
                                                <td>{{ $detalle->jabon->nombre }}</td>
                                                <td>{{ $detalle->descripcion_adicionales }}</td>
                                                <td>{{ $detalle->subtotal}}</td>
                                            </tr>
                                        @endforeach
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection
@section('js')
    <script>
        $(document).ready(function () {
            var tablaPedidos = $('#tabla_detalles').DataTable({
                order: [[0, 'asc']],
                columnDefs: [
                    { targets: [2], orderable: false },
                ],
            });

            $(document).on('click', '.btn-eliminar', function () {
                var idPedido = $(this).data('id');
                var action = "{{ route('pedidos.destroy', ':id') }}".replace(':id', idPedido);

                $('#form_eliminar').attr('action', action);
                $('#pedido_id').text(idPedido);
            });

            $('.actualizar-estado').change(function () {
                var idPedido = $(this).data('id');
                var nuevoEstado = $(this).val();

                $.ajax({
                    url: "{{ route('pedidos.update', ':id') }}".replace(':id', idPedido),
                    method: 'PUT',
                    data: {
                        _token: "{{ csrf_token() }}",
                        estado: nuevoEstado,
                    },
                    success: function () {
                    },
                });
                var modal = new bootstrap.Modal(document.getElementById('modal_actualizado'));
                modal.show();
            });
        });
    </script>
@endsection